#!/bin/sh

for md in /dev/md* ; do
	if [ -b "${md}" ]; then
		wipefs -a -f "${md}" >> /tmp/wipe.log
		echo "wiped ${part}" >> /tmp/wipe.log
		mdadm --stop ${md}
		echo "stopped ${md}" >> /tmp/wipe.log
	fi
done
for part in $(list-devices partition); do
	if [ -b "${part}" ]; then
		wipefs -a -f ${part} >> /tmp/wipe.log
		echo "wiped ${part}" >> /tmp/wipe.log
	fi
done
for disk in $(list-devices disk); do
	if [ -b "${disk}" ]; then
		wipefs -a -f ${disk} >> /tmp/wipe.log
		dd if=/dev/zero of=${disk} bs=512 count=32
		blkdiscard --secure ${disk}
		echo "wiped ${disk}" >> /tmp/wipe.log
	fi
done

set $(list-devices disk)
let numb=$#/2
DISKA=$1
DISKB=$2

getpart() {
	local partnum disk
	disk=${1}
	partnum=${2}
	if echo "${disk}" | grep -q nvme; then
		echo "${disk}p${partnum}"
	else
		echo "${disk}${partnum}"
	fi
}

get_raid_parts() {
	local partnum disks resstr del
	partnum=${1}
	shift
	disks=${@}
	for disk in ${disks}; do
		if [ -n "${resstr}" ]; then
			del="#"
		else
			del=""
		fi
		resstr="${resstr}${del}$(getpart ${disk} ${partnum})"
	done
	echo ${resstr}
}

debconf-set partman-basicfilesystems/choose_label gpt
debconf-set partman-partitioning/choose_label gpt
debconf-set partman-basicfilesystems/default_label gpt
debconf-set partman-partitioning/default_label gpt
debconf-set partman-partitioning/choose_label gpt

debconf-set partman-auto/disk "$DISKA $DISKB"
debconf-set partman-auto/method "raid"

bootsize=525
efisize=525
swapsize=2098

if [ -d /sys/firmware/efi ]; then
	debconf-set partman-auto/expert_recipe "multiraid :: \
		 ${efisize} 200 ${efisize} free \$iflabel{ gpt } \$reusemethod{ } method{ efi } format{ } . \
		 ${bootsize} 50 ${bootsize} raid \$primary{ } method{ raid } . \
		 132 500 ${swapsize} raid method{ raid } . \
		 4195 10000 -1 raid method{ raid } . "
	echo "$(getpart ${DISKA} 1)" >> /tmp/first_efi_part
	echo "$(getpart ${DISKB} 1)" >> /tmp/second_efi_parts
else
	debconf-set partman-auto/expert_recipe "multiraid :: \
		 2 1 2 free \$iflabel{ gpt } method{ biosgrub } . \
		 ${bootsize} 50 ${bootsize} raid \$primary{ } method{ raid } . \
		 132 500 ${swapsize} raid method{ raid } . \
		 4195 10000 -1 raid method{ raid } . "
fi

debconf-set partman-auto-raid/recipe " \
	 1 2 0 ext4 /boot $(get_raid_parts 2 ${DISKA} ${DISKB}) . \
	 0 2 0 swap - $(get_raid_parts 3 ${DISKA} ${DISKB}) . \
	 0 2 0 ext4 / $(get_raid_parts 4 ${DISKA} ${DISKB}) . "

debconf-set grub-installer/bootdev "${DISKA} ${DISKB}"
echo "${DISKA} ${DISKB}" >> /tmp/grub_devices
